query GetQueryEntity($urn: String!) {
  entity(urn: $urn) {
    urn
    type
    ... on QueryEntity {
      urn
      properties {
        name
        description
        source
        statement {
          value
          language
        }
        lastModified {
          actor
        }
      }
      platform {
        urn
        name
      }
      subjects {
        dataset {
          urn
          name
        }
        schemaField {
          urn
          type
          fieldPath
        }
      }
    }
  }
}

